:orphan:

`plasmapy.dispersion.analytical.mhd_waves_`
===============================================

.. currentmodule:: plasmapy.dispersion.analytical.mhd_waves_

.. automodapi:: plasmapy.dispersion.analytical.mhd_waves_
